# Generated by Django 3.1 on 2020-08-28 20:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("traktor", "0005_add_user_to_project"),
    ]

    operations = [
        migrations.AlterField(
            model_name="project", name="slug", field=models.SlugField(),
        ),
        migrations.AlterUniqueTogether(
            name="project", unique_together={("user", "slug")},
        ),
    ]
