# Generated by Django 3.1 on 2020-08-20 17:37

from django.db import migrations, models
import django.utils.timezone
import tea_django.models.mixins.colored


class Migration(migrations.Migration):

    dependencies = [
        ("traktor", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="entry",
            name="description",
            field=models.CharField(blank=True, default="", max_length=1023),
        ),
        migrations.AlterField(
            model_name="entry",
            name="notes",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="entry",
            name="start_time",
            field=models.DateTimeField(
                blank=True, default=django.utils.timezone.now
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="color",
            field=tea_django.models.mixins.colored.ColorField(
                default="#FFFFFF", max_length=7
            ),
        ),
        migrations.AlterField(
            model_name="task",
            name="color",
            field=tea_django.models.mixins.colored.ColorField(
                default="#FFFFFF", max_length=7
            ),
        ),
    ]
