# Generated by Django 3.1 on 2020-08-23 17:58

from django.db import migrations, models
import tea.timestamp


class Migration(migrations.Migration):

    dependencies = [
        ("traktor", "0003_user"),
    ]

    operations = [
        migrations.AlterField(
            model_name="entry",
            name="start_time",
            field=models.DateTimeField(blank=True, default=tea.timestamp.now),
        ),
    ]
